Package 'zueriverse'

Title: dummy package to gather the documentation about zueriverse packages
Description: Package without exported functionality, created for documentation purposes, gathering all information about zueriverse packages in one place.
Authors: Alessandro Feller [aut, cre], Sara Hänzi [aut], Statistik Stadt Zürich [cph, fnd]
Maintainer: Alessandro Feller <[email protected]>
License: MIT + file LICENSE
Version: 0.1.0
Built: 2026-05-25 07:52:51 UTC
Source: https://github.com/StatistikStadtZuerich/zueriverse

Help Index